# coding: utf-8

"""
    FreeClimb API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import freeclimb
from freeclimb.models.recording_result import RecordingResult  # noqa: E501
from freeclimb.rest import ApiException


class TestRecordingResult(unittest.TestCase):
    """RecordingResult unit test stubs"""

    def setUp(self):
        self.recording_result = RecordingResult()

    def tearDown(self):
        pass

    def testRecordingResult(self):
        """Test RecordingResult"""
        # construct object with mandatory attributes with example values
        # model = freeclimb.models.recording_result.RecordingResult()  # noqa: E501
        self.assertTrue(isinstance(self.recording_result, RecordingResult))


if __name__ == '__main__':
    unittest.main()
